@@ -37,7 +37,8 @@ function(funs=NULL)
    extract.functions <- unique(functions)
    extract.variables <- unique(variables)
     
-   extract.fun.list <- list(packages=extract.packages, functions=extract.functions, variables=extract.variables)
+   extract.fun.list <- list(packages=extract.packages, 
+        functions=extract.functions, variables=extract.variables)
    extract.fun.list
 }
 
